# Security Policy

## Supported Versions

FastMCP v2.x receives security updates. Earlier versions are no longer supported.

| Version | Supported          |
| ------- | ------------------ |
| 2.x     | :white_check_mark: |
| < 2.0   | :x:                |

## Reporting a Vulnerability

Please report security vulnerabilities privately using [GitHub's security advisory feature](https://github.com/jlowin/fastmcp/security/advisories/new).

Do not open public issues for security concerns.
